#
# spec file for package python-apsw
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define tarver  3.35.4-r1
Name:           python-apsw
Version:        3.35.4_r1
Release:        bp154.1.27
Summary:        Another Python SQLite Wrapper
License:        Zlib
Group:          Development/Libraries/Python
URL:            https://github.com/rogerbinns/apsw/
Source:         https://github.com/rogerbinns/apsw/archive/%{tarver}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(sqlite3) >= 3.30
%python_subpackages

%description
APSW is a Python wrapper for the SQLite embedded relational database
engine. In contrast to other wrappers such as pysqlite it focuses on
being a minimal layer over SQLite attempting just to translate the
complete SQLite API into Python.

%prep
%setup -q -n apsw-%{tarver}

%build
export CFLAGS="%{optflags} -fno-strict-aliasing"
#%%python_build
%{python_expand $python setup.py build --enable-all-extensions --enable=load_extension}

%install
%python_install

%check
# python setup.py test is in this case very complicated home-brewn,
# and using unittest, so it shouldn't be affected by changes in
# setuptools.
export CFLAGS="%{optflags} -fno-strict-aliasing"
%{python_expand $python setup.py build_ext --inplace
$python setup.py test
$python setup.py clean
}

%files %{python_files}
%license LICENSE
%doc README.rst
%{python_sitearch}/*

%changelog
* Fri Jun 25 2021 ecsos <ecsos@opensuse.org>
- Update to 3.35.4-r1:
  - Updates for SQLite download url (the year is part of the urls).
  - Added enable flag for built-in SQL math functions, and enable
    it by default with –enable-all-extensions.
  - Use the newer buffer API for Python 3
    (old API removed in Python 3.10).
- Fix loadable extensions are missing,
  so insert --enable-all-extensions and --enable=load_extension.
  See: https://rogerbinns.github.io/apsw/build.html#building
* Tue Dec 29 2020 Dirk Müller <dmueller@suse.com>
- udpate to 3.34.0-r1:
  * Windows MSI installer files are now provided
  * Added Connection.txn_state()
  * Added constants: SQLITE_IOERR_CORRUPTFS
* Tue Sep 22 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix the source url to really match reality
* Tue Sep 22 2020 Hans-Peter Jansen <hpj@urpla.net>
- Update to 3.33.0-r1:
  * Small performance improvement in string handling
  * apsw module exposes Cursor, Blob, and Backup types (issue #273)
  * pkg-config is used to detect International Components for
    Unicode (ICU) sdk when the SQLite ICU extension is enabled. It
    falls back to icu-config as before. (issue #268).
- Update to 3.32.2-r2:
  * Added some constants
  * Minor documentation updates
- Fix source URL
* Tue Mar  3 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update the sqlite dependency
- Update to 3.31.1:
  * Fix deprecated universal newline use in shell (#283)
  * Shell now uses pragma function_list to get list of functions for tab completion
* Tue Feb  4 2020 Ondřej Súkup <mimi.vx@gmail.com>
- update to 3.30.1-r1
- drop 0002-Skip-one-test-on-python3.8.patch
    0001-py3.8-avoid-invalid-escapes.patch
  * Updated hashing of SQL statements
  * Updated Connection.config() with all current SQLITE_DBCONFIG constants
* Tue Sep 10 2019 Tomáš Chvátal <tchvatal@suse.com>
- Add more py3.8 patches:
  * 0001-py3.8-avoid-invalid-escapes.patch
  * 0002-Skip-one-test-on-python3.8.patch
- Remove patch obsoleted by above python38.patch
* Thu Jul  4 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.28.0-r1:
  * No changelog
- Add patch to build with python 3.8:
  * python38.patch
* Thu Aug 31 2017 toddrme2178@gmail.com
- Update to version 3.9.2-r1
  * No changelog
* Thu Aug 24 2017 jmatejek@suse.com
- singlespec auto-conversion
* Tue Oct 15 2013 tchvatal@suse.com
- Downgrade to 3.7.17 so we build on 13.1 too.
* Tue Oct 15 2013 tomas.chvatal@gmail.com
- Fix file collision between doc and normal
* Mon Oct 14 2013 tchvatal@suse.com
- Version bump to 3.8.0.2-r1 to use latest sqlite queries.
- Drop the macroed commands in favor of normal ones
- Drop clean section
- Write fully what documents go where.
* Wed Oct  9 2013 hrvoje.senjan@gmail.com
- Drop unused tarballs, defines and checks for obsolete openSUSE versions
* Tue Sep  3 2013 jw@suse.com
- osc service localrun format_spec_file
  to add comments and such.
* Mon Dec 12 2011 pascal.bleser@opensuse.org
- build for all supported versions from a single spec
- link dynamically against the sqlite3 version that ships with each distro
  version, rather than using amalgamation: this is required by s3ql
* Mon Aug  9 2010 pascal.bleser@opensuse.org
- initial package (3.7.0.1-r1)
